package com.staffing.custom.mapper;

import java.util.List;
import com.staffing.custom.domain.StTaskSign;
import org.apache.ibatis.annotations.Param;

/**
 * 签到Mapper接口
 * 
 * @author staffing
 * @date 2024-08-27
 */
public interface StTaskSignMapper 
{
    /**
     * 查询签到
     * 
     * @param id 签到主键
     * @return 签到
     */
    public StTaskSign selectStTaskSignById(Long id);


    public StTaskSign selectStTaskSignByTaskIdAndUserId(@Param("taskId") Long tid, @Param("uid") Long uid);

    public List<StTaskSign> selectStTaskSignByTaskIds(@Param("taskIds") List<Long> id);
    /**
     * 查询签到列表
     * 
     * @param stTaskSign 签到
     * @return 签到集合
     */
    public List<StTaskSign> selectStTaskSignList(StTaskSign stTaskSign);

    /**
     * 新增签到
     * 
     * @param stTaskSign 签到
     * @return 结果
     */
    public int insertStTaskSign(StTaskSign stTaskSign);

    /**
     * 修改签到
     * 
     * @param stTaskSign 签到
     * @return 结果
     */
    public int updateStTaskSign(StTaskSign stTaskSign);

    int updateStTaskSignByEmId(StTaskSign stTaskSign);

    int updateStTaskSignByTaskId(StTaskSign stTaskSign);

    int updateStTaskSignByTaskIdAndEmId(StTaskSign stTaskSign);
    /**
     * 删除签到
     * 
     * @param id 签到主键
     * @return 结果
     */
    public int deleteStTaskSignById(Long id);

    /**
     * 批量删除签到
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteStTaskSignByIds(Long[] ids);
}
